@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -36,22 +36,13 @@
 
 CHEROKEE_BEGIN_DECLS
 
-typedef enum {
-	hstat_unset,
-	hstat_sending,
-	hstat_forbidden,
-	hstat_file_not_found,
-	hstat_error
-} cherokee_handler_status_t;
-
 typedef enum {
 	hsupport_nothing       = 0,
 	hsupport_length        = 1,         /* Knows the length. Eg: for keep-alive    */
 	hsupport_maybe_length  = 1 << 1,    /* It might include content-length         */
 	hsupport_range         = 1 << 2,    /* Can handle "Range: bytes=" requests     */
 	hsupport_error         = 1 << 3,    /* It is an error handler                  */
-	hsupport_full_headers  = 1 << 4,    /* Handler adds the full header stack      */
-	hsupport_skip_headers  = 1 << 5     /* The server shouldn't add any headers    */
+	hsupport_full_headers  = 1 << 4     /* Handler adds the full header stack      */
 } cherokee_handler_support_t;
 
 
