@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2009 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -86,8 +86,8 @@
 # define no_return
 #endif
 
-#define DEFAULT_RECV_SIZE             2048
-#define DEFAULT_READ_SIZE             8192
+#define DEFAULT_RECV_SIZE             ( 2 * 1024)
+#define DEFAULT_READ_SIZE             (16 * 1024)
 #define MAX_HEADER_LEN                8192
 #define MAX_HEADER_CRLF               8
 #define MAX_KEEPALIVE                 500
@@ -96,8 +96,7 @@
 #define TERMINAL_WIDTH                80
 #define DEFAULT_TRAFFIC_UPDATE        10
 #define CGI_TIMEOUT                   65
-#define MSECONDS_TO_LINGER            2000
-#define POST_SIZE_TO_DISK             32768
+#define SECONDS_TO_LINGER             2
 #define LOGGER_MIN_BUFSIZE            0
 #define DEFAULT_LOGGER_MAX_BUFSIZE    32768
 #define LOGGER_MAX_BUFSIZE            (4 * 1024 * 1024)
@@ -107,6 +106,8 @@
 #define SENDFILE_MAX_SIZE             2147483647     /* 2Gb -1*/
 #define NONCE_CLEANUP_LAPSE           60
 #define NONCE_EXPIRATION              60
+#define POST_READ_SIZE                32700
+#define FLCACHE_LAPSE                 60
 
 #define FD_NUM_SPARE                  10        /* range:  8 ... 20    */
 #define FD_NUM_MIN_SYSTEM             20        /* range: 16 ... 64    */
@@ -114,9 +115,10 @@
 #define FD_NUM_MIN_PER_THREAD         8         /* range:  8 ... 65000 */
 #define FD_NUM_CUSTOM_LIMIT           4096      /* range: 16 ... 65000 */
 
-#define EXIT_OK                        0
-#define EXIT_ERROR                     1
-#define EXIT_OK_ONCE                   2
+#define EXIT_OK                       0
+#define EXIT_ERROR                    1
+#define EXIT_OK_ONCE                  2
+#define EXIT_ERROR_FATAL              3
 
 #if (FD_NUM_MIN_SYSTEM < 16)
 # error FD_NUM_MIN_SYSTEM too low, < 16
@@ -154,28 +156,30 @@
 	(strncasecmp(m, str, sizeof(str)-1) == 0)
 
 #define equal_buf_str(b,str) \
-	(cherokee_buffer_case_cmp_str(b,str) == 0)
+	(cherokee_buffer_case_cmp_str((b),(str)) == 0)
 
 #define return_if_fail(expr,ret) \
-	if (!(expr)) {                                                      \
-		fprintf (stderr,                                            \
-       		         "file %s: line %d (%s): assertion `%s' failed\n",  \
-                          __FILE__,                                         \
-                          __LINE__,                                         \
-                          __cherokee_func__,                                \
-                          #expr);                                           \
-	        return (ret);                                               \
-	}
+	do {								\
+		if (!(expr)) {						\
+			PRINT_ERROR ("assertion `%s' failed\n", #expr);	\
+			return (ret);					\
+		}							\
+	} while(0)
 
-
-#define SHOULDNT_HAPPEN \
-	do { fprintf (stderr, "file %s:%d (%s): this should not happen\n",  \
-		      __FILE__, __LINE__, __cherokee_func__);               \
+#define SHOULDNT_HAPPEN							\
+	do {								\
+		fprintf (stderr,					\
+			 "file %s:%d (%s): this should not happen\n",	\
+			 __FILE__, __LINE__, __cherokee_func__);	\
+		fflush (stderr);					\
 	} while (0)
 
-#define RET_UNKNOWN(ret) \
-	do { fprintf (stderr, "file %s:%d (%s): ret code unknown ret=%d\n", \
-		      __FILE__, __LINE__, __cherokee_func__, ret);          \
+#define RET_UNKNOWN(ret)						\
+	do {								\
+		fprintf (stderr,					\
+			 "file %s:%d (%s): ret code unknown ret=%d\n",	\
+			 __FILE__, __LINE__, __cherokee_func__, ret);	\
+		fflush (stderr);					\
 	} while (0)
 
 #define UNUSED(x) ((void)(x))
@@ -264,7 +268,10 @@
 		CHEROKEE_NEW_STRUCT (n, klass);                       \
 		                                                      \
 		ret = cherokee_ ## klass ## _init (n);                \
-		if (unlikely (ret != ret_ok)) return ret;             \
+		if (unlikely (ret != ret_ok)) {			      \
+			free (n);				      \
+			return ret;				      \
+		}						      \
 		                                                      \
 		*obj = n;                                             \
 		return ret_ok;                                        \
@@ -273,7 +280,7 @@
 #define CHEROKEE_ADD_FUNC_FREE(klass)  \
 	ret_t                                                         \
 	cherokee_ ## klass ## _free (cherokee_ ## klass ## _t *obj) { \
-		if (obj == NULL)				      \
+		if ((obj) == NULL)				      \
 			return ret_ok;				      \
 								      \
 		cherokee_ ## klass ## _mrproper (obj);                \
@@ -286,24 +293,24 @@
 /* Printing macros
  */
 #if defined(__GNUC__) || ( defined(__SUNPRO_C) && __SUNPRO_C > 0x590 )
-# define PRINT_MSG(fmt,arg...)    fprintf(stderr, fmt, ##arg)
-# define PRINT_ERROR(fmt,arg...)  fprintf(stderr, "%s:%d - "fmt, __FILE__, __LINE__, ##arg)
+# define PRINT_MSG(fmt,arg...)    do { fprintf(stderr, fmt, ##arg); fflush(stderr); } while(0)
+# define PRINT_ERROR(fmt,arg...)  do { fprintf(stderr, "%s:%d - "fmt, __FILE__, __LINE__, ##arg); fflush(stderr); } while(0)
 #else
-# define PRINT_MSG(fmt,...)       fprintf(stderr, fmt, __VA_ARGS__)
-# define PRINT_ERROR(fmt,...)     fprintf(stderr, "%s:%d - "fmt, __FILE__, __LINE__, __VA_ARGS__)
+# define PRINT_MSG(fmt,...)       do { fprintf(stderr, fmt, __VA_ARGS__); fflush(stderr); } while(0)
+# define PRINT_ERROR(fmt,...)     do { fprintf(stderr, "%s:%d - "fmt, __FILE__, __LINE__, __VA_ARGS__); fflush(stderr); } while(0)
 #endif
 
 #ifdef DEBUG
 # ifdef __GNUC__
 #  define PRINT_DEBUG(fmt,arg...) do { fprintf(stdout, "%s:%d - " fmt,__FILE__,__LINE__,##arg); fflush(stdout); } while (0)
 # else
-#  define PRINT_DEBUG(fmt,...) do { fprintf(stdout, "%s:%d - " fmt,__FILE__,__LINE__,__VA_ARGS__); fflush(stdout); } while (0)
+#  define PRINT_DEBUG(fmt,...)    do { fprintf(stdout, "%s:%d - " fmt,__FILE__,__LINE__,__VA_ARGS__); fflush(stdout); } while (0)
 # endif
 #else
 # ifdef __GNUC__
 #  define PRINT_DEBUG(fmt,arg...) do { } while(0)
 # else
-#  define PRINT_DEBUG(fmt,...) do { } while(0)
+#  define PRINT_DEBUG(fmt,...)    do { } while(0)
 # endif
 #endif
 
@@ -403,4 +410,13 @@
 		cherokee_buffer_mrproper (&tmp);		\
 	} while (0)
 
+
+#define CHEROKEE_CHAR_IS_WHITE(_ch)     (((_ch) == ' ') || ((_ch) == '\t') || ((_ch) == '\n'))
+#define CHEROKEE_CHAR_IS_UPPERCASE(_ch) (((_ch) >= 'A') && ((_ch) <= 'Z'))
+#define CHEROKEE_CHAR_IS_LOWERCASE(_ch) (((_ch) >= 'a') && ((_ch) <= 'z'))
+#define CHEROKEE_CHAR_IS_DIGIT(_ch)     (((_ch) >= '0') && ((_ch) <= '9'))
+#define CHEROKEE_CHAR_TO_LOWER(_ch)     ((_ch) | 32)
+#define CHEROKEE_CHAT_TO_UPPER(_ch)     ((_ch) & ~32)
+
+
 #endif /* CHEROKEE_MACROS_H */
