@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2010 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2011 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -54,6 +54,10 @@
 # include <sys/uio.h>
 #endif
 
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
+
 #include <time.h>
 #include <dirent.h>
 #include <errno.h>
@@ -73,10 +77,8 @@ CHEROKEE_BEGIN_DECLS
 # define cherokee_stat(path,buf)   cherokee_win32_stat(path,buf)
 # define cherokee_lstat(path,buf)  cherokee_win32_stat(path,buf)
 # define cherokee_error            GetLastError()
-# define cherokee_mkdir(path,perm) mkdir(path)
 #else
 # define cherokee_error            errno
-# define cherokee_mkdir(path,perm) mkdir(path,perm)
 #endif
 
 /* Missing functions
@@ -94,6 +96,11 @@ size_t strlcat (char *dst, const char *src, size_t siz);
 void *rpl_malloc (size_t n);
 #endif
 
+char *strncasestr  (const char *s, const char *find, size_t slen);
+char *strncasestrn (const char *s, size_t slen, const char *find, size_t findlen);
+
+#define strncasestrn_s(s,s_len,lit) strncasestrn(s, s_len, lit, sizeof(lit)-1)
+
 /* Constants
  */
 extern const char hex2dec_tab[256];
@@ -133,8 +140,8 @@ ret_t   cherokee_buf_add_backtrace  (cherokee_buffer_t *buf, int n_skip, const c
 ret_t   cherokee_find_exec_in_path  (const char        *bin_name,
 				     cherokee_buffer_t *fullpath);
 
-ret_t   cherokee_atoi               (const char        *str,
-				     int               *ret_value);
+ret_t   cherokee_atoi               (const char *str, int *ret_value);
+ret_t   cherokee_atob               (const char *str, cherokee_boolean_t *ret_value);
 
 /* Time management functions
  */
@@ -144,19 +151,42 @@ long      *cherokee_get_timezone_ref (void);
 
 /* Thread safe functions
  */
+DIR * cherokee_opendir       (const char *dirname);
 int   cherokee_readdir       (DIR *dirstream, struct dirent *entry, struct dirent **result);
+int   cherokee_closedir      (DIR *dirstream);
+
 int   cherokee_stat          (const char *restrict path, struct stat *buf);
 int   cherokee_lstat         (const char *restrict path, struct stat *buf);
 int   cherokee_fstat         (int filedes, struct stat *buf);
-ret_t cherokee_gethostbyname (const char *hostname, void *addr);
+int   cherokee_access        (const char *pathname, int mode);
+int   cherokee_open          (const char *path, int oflag, int mode);
+int   cherokee_unlink        (const char *path);
+int   cherokee_pipe          (int fildes[2]);
+
+ret_t cherokee_gethostbyname (cherokee_buffer_t *hostname, struct addrinfo **addr);
+
 ret_t cherokee_gethostname   (cherokee_buffer_t *buf);
 ret_t cherokee_syslog        (int priority, cherokee_buffer_t *buf);
+
 ret_t cherokee_getpwnam      (const char *name, struct passwd *pwbuf, char *buf, size_t buflen);
+ret_t cherokee_getpwuid      (uid_t uid, struct passwd *pwbuf, char *buf, size_t buflen);
+ret_t cherokee_getpwnam_uid  (const char *name, struct passwd *pwbuf, char *buf, size_t buflen);
 ret_t cherokee_getgrnam      (const char *name, struct group *pwbuf, char *buf, size_t buflen);
+ret_t cherokee_getgrgid      (gid_t gid, struct group *pwbuf, char *buf, size_t buflen);
+ret_t cherokee_getgrnam_gid  (const char *name, struct group *pwbuf, char *buf, size_t buflen);
+
 ret_t cherokee_mkstemp       (cherokee_buffer_t *buffer, int *fd);
+ret_t cherokee_mkdtemp       (char *template);
+
+ret_t cherokee_mkdir         (const char *path, int mode);
 ret_t cherokee_mkdir_p       (cherokee_buffer_t *path, int mode);
-ret_t cherokee_ntop          (int family, struct sockaddr *addr, char *dst, size_t cnt);
 ret_t cherokee_mkdir_p_perm  (cherokee_buffer_t *dir_path, int create_mode, int ensure_perm);
+ret_t cherokee_rm_rf         (cherokee_buffer_t *path, uid_t uid);
+
+void cherokee_random_seed    (void);
+long cherokee_random         (void);
+
+ret_t cherokee_ntop          (int family, struct sockaddr *addr, char *dst, size_t cnt);
 ret_t cherokee_wait_pid      (int pid, int *retcode);
 ret_t cherokee_reset_signals (void);
 
@@ -172,6 +202,7 @@ ret_t cherokee_io_stat       (cherokee_iocache_t        *iocache,
 ret_t cherokee_fd_set_nonblocking (int fd, cherokee_boolean_t enable);
 ret_t cherokee_fd_set_nodelay     (int fd, cherokee_boolean_t enable);
 ret_t cherokee_fd_set_closexec    (int fd);
+ret_t cherokee_fd_set_reuseaddr   (int fd);
 ret_t cherokee_fd_close           (int fd);
 
 /* Misc
@@ -179,7 +210,6 @@ ret_t cherokee_fd_close           (int fd);
 ret_t cherokee_sys_fdlimit_get (cuint_t *limit);
 ret_t cherokee_sys_fdlimit_set (cuint_t  limit);
 ret_t cherokee_get_shell       (const char **shell, const char **binary);
-void  cherokee_print_wrapped   (cherokee_buffer_t *buffer);
 ret_t cherokee_tmp_dir_copy    (cherokee_buffer_t *buffer);
 
 /* IO vectors
@@ -214,7 +244,11 @@ ret_t cherokee_split_arguments    (cherokee_buffer_t *request,
 ret_t cherokee_parse_query_string (cherokee_buffer_t *qstring,
 				   cherokee_avl_t  *arguments);
 
-char *cherokee_header_get_next_line (char *line);
+char  *cherokee_header_get_next_line (char *line);
+ret_t  cherokee_header_del_entry     (cherokee_buffer_t *header,
+				      const char        *header_name,
+				      int                header_name_len);
+
 
 CHEROKEE_END_DECLS
 
