@@ -3,7 +3,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2009-2010 Alvaro Lopez Ortega
+# Copyright (C) 2010-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -114,15 +114,22 @@ class PluginSelector (Widget):
         # Properties
         self._key   = key
         self._mods  = modules
-        self._url   = '/plugin_content_%s' %(key_to_url(key))
         active_name = cfg.get_val (self._key)
 
+        # URL
+        self._url = '/plugin_content_%s' %(key_to_url(key))
+
+        srv = get_server()
+        if srv.use_sec_submit:
+            self._url += '?key=%s' %(srv.sec_submit)
+
         # Widgets
         self.selector_widget = ComboCfg (key, modules)
         self.plugin          = instance_plugin (active_name, key, **kwargs)
 
         # Register hidden URL for the plugin content
-        publish (self._url, PluginInstanceProxy, key=key, modules=modules, method='POST', **kwargs)
+        publish (r'^/plugin_content_%s' %(key_to_url(key)), PluginInstanceProxy,
+                 key=key, modules=modules, method='POST', **kwargs)
 
     def _get_helps (self):
         global_key  = self._key.replace('!','_')
@@ -185,6 +192,11 @@ def load_module_pyc (fullpath_pyc, namespace, use_cache=True, load_src=True):
             return imp.load_compiled (namespace, fullpath)
 
 
+def unload_module (name):
+    if name in sys.modules:
+        del (sys.modules[name])
+
+
 def load_module (name, dirname):
     # Sanity check
     if not name:
@@ -202,7 +214,11 @@ def load_module (name, dirname):
 
     # Shortcut: it might be loaded
     if sys.modules.has_key (name):
-        if sys.modules[name].__file__ == fullpath:
+        loaded_mod_file = sys.modules[name].__file__
+        if loaded_mod_file.endswith('.pyc'):
+            loaded_mod_file = loaded_mod_file[:-1]
+
+        if loaded_mod_file == fullpath:
             return sys.modules[name]
 
     # Load the plug-in
