@@ -92,6 +92,30 @@ class ServerHandler (pyscgi.SCGIHandler):
         # Get a copy of the server (it did fork!)
         server = get_server()
 
+        # Security Checks
+        sec_error = False
+        if server.use_sec_cookie:
+            if not self.env['CTK_COOKIE']:
+                sec_error = "Cookie"
+            elif not server.sec_cookie:
+                server.sec_cookie = self.env['CTK_COOKIE'][:]
+            else:
+                if server.sec_cookie != self.env['CTK_COOKIE']:
+                    sec_error = "Cookie"
+
+        if server.use_sec_submit:
+            if not server.sec_submit:
+                server.sec_submit = self.env['CTK_SUBMITTER_SECRET'][:]
+
+            if self.env['REQUEST_METHOD'] == 'POST':
+                if not server.sec_submit in url:
+                    sec_error = "Submit"
+
+        if sec_error:
+            response = HTTP_Response (error=403, body="%s check failed" %(sec_error))
+            self.send (str(response))
+            return
+
         # Refer SCGI object by thread
         my_thread = threading.currentThread()
         my_thread.scgi_conn   = self
@@ -174,11 +198,16 @@ class ServerHandler (pyscgi.SCGIHandler):
 
 class Server:
     def __init__ (self):
-        self._web_paths = []
-        self._scgi        = None
-        self._is_init     = False
-        self.lock         = threading.RLock()
-        self.plugin_paths = []
+        self._web_paths     = []
+        self._scgi          = None
+        self._is_init       = False
+        self.lock           = threading.RLock()
+        self.plugin_paths   = []
+        self.exiting        = False
+        self.use_sec_cookie = False
+        self.sec_cookie     = None
+        self.use_sec_submit = False
+        self.sec_submit     = None
 
     def init_server (self, *args, **kwargs):
         # Is it already init?
@@ -186,6 +215,13 @@ class Server:
             return
         self._is_init = True
 
+        # Security cookie/submit
+        if 'sec_cookie' in kwargs:
+            self.use_sec_cookie = kwargs.pop('sec_cookie')
+
+        if 'sec_submit' in kwargs:
+            self.use_sec_submit = kwargs.pop('sec_submit')
+
         # Instance SCGI server
         self._scgi = pyscgi.ServerFactory (*args, **kwargs)
 
@@ -236,12 +272,16 @@ class Server:
 
     def serve_forever (self):
         try:
-            while True:
+            while not self.exiting:
                 # Handle request
                 self._scgi.handle_request()
+                if self.exiting:
+                    break
         except KeyboardInterrupt:
-            print "\r", "CTK Back-end Server exiting.."
-            self._scgi.server_close()
+            self.exiting = True
+
+        print "\r", "CTK Back-end Server exiting.."
+        self._scgi.server_close()
 
 
 #
@@ -254,6 +294,8 @@ def cfg_reply_ajax_ok():
     return {'ret':'ok', 'not-modified': '#save-button'}
 
 def cfg_apply_post():
+    """Apply entries of the HTTP POST request to the Configuration
+    tree"""
     for k in post:
         cfg[k] = post[k]
 
@@ -269,6 +311,7 @@ def get_server():
     return __global_server
 
 def get_scgi():
+    """Retrieve SCGI object for current connection"""
     my_thread = threading.currentThread()
     return my_thread.scgi_conn
 
@@ -300,6 +343,10 @@ def run (*args, **kwargs):
     srv = get_server()
     srv.serve_forever()
 
+def stop():
+    srv = get_server()
+    srv.exiting = True
+
 def step ():
     srv = get_server()
     srv._scgi.handle_request()
@@ -314,6 +361,8 @@ class Publish_FakeClass:
 
 
 def publish (regex_url, klass, **kwargs):
+    """Publish a path given by the regex_url regular expression, and
+    map it to the class of function given by the klass argument"""
     # Instance object
     if type(klass) == types.ClassType:
         obj = klass()
@@ -331,6 +380,7 @@ def publish (regex_url, klass, **kwargs):
     server.add_route (obj)
 
 def unpublish (regex_url):
+    """Unpublish a path from the global list of published URLs"""
     # Unregister
     server = get_server()
     server.remove_route (regex_url)
@@ -389,6 +439,10 @@ class _Post:
         post = my_thread.post
         return post.get_all(*args)
 
+    def get_raw (self):
+        my_thread = threading.currentThread()
+        post = my_thread.post
+        return post.raw_post
 
 class _Request:
     def _get_request_url (self):
