@@ -5,7 +5,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2001-2010 Alvaro Lopez Ortega
+# Copyright (C) 2001-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -98,8 +98,9 @@ def is_new_bind (port, ip=None):
 
 def commit():
     # Add a new port
-    port = CTK.post.pop('new_port')
+    port      = CTK.post.pop('new_port')
     interface = CTK.post.pop('new_if')
+
     if port:
         try:
             is_new_bind (port, interface)
@@ -109,10 +110,16 @@ def commit():
 
         # Look for the next entry
         pre = CTK.cfg.get_next_entry_prefix ('server!bind')
+
+        # Add new port
         CTK.cfg['%s!port'%(pre)] = port
         if interface:
             CTK.cfg['%s!interface'%(pre)] = interface
 
+        # Auto-set TLS/SSL flag
+        if int(port) == 443:
+            CTK.cfg['%s!tls'%(pre)] = "1"
+
     # Modifications
     return CTK.cfg_apply_post()
 
