@@ -48,7 +48,8 @@ NOTE_SOURCE        = N_('The source can be either a local interpreter or a remot
 NOTE_NICK          = N_('Source nick. It will be referenced by this name in the rest of the server.')
 NOTE_TYPE          = N_('It allows to choose whether it runs the local host or a remote server.')
 NOTE_HOST          = N_('Where the information source can be accessed. The host:port pair, or the Unix socket path.')
-NOTE_INTERPRETER   = N_('Command to spawn a new source in case it were not accessible.')
+NOTE_INTERPRETER1  = N_('Command to spawn a new source in case it were not running.')
+NOTE_INTERPRETER2  = N_('REMEMBER: The interpreter MUST NOT run as a daemon or detach itself from its parent process.')
 NOTE_TIMEOUT       = N_('How long should the server wait when spawning an interpreter before giving up (in seconds). Default: 3.')
 NOTE_USAGE         = N_('Sources currently in use. Note that the last source of any rule cannot be deleted until the rule has been manually edited.')
 NOTE_USER          = N_('Execute the interpreter under a different user. Default: Same UID as the server.')
@@ -67,6 +68,7 @@ VALIDATIONS = [
     ('tmp!new_host',           validations.is_safe_information_source_host),
     ('tmp!new_nick',           validations.is_safe_information_source_nick),
     ("source_clone_trg",       validations.is_safe_id),
+    ("source!.+?!interpreter", validations.is_not_empty),
 ]
 
 HELPS = [('config_info_sources', N_("Information Sources"))]
@@ -154,17 +156,21 @@ def _all_sources_per_rule ():
             sources = _sources_per_rule (rule)
             if sources:
                 result.append({rule: sources})
+
     return result
 
 
 def _sources_per_rule (rule):
     """Return list of sources used by a given rule"""
-    sources  = []
-    pre      = '%s!handler!balancer!source'%(rule)
-    src_keys = CTK.cfg.keys(pre)
+    sources = []
+    handler = CTK.cfg.get_val('%s!handler'%(rule))
+
+    if handler in HANDLERS_WITH_BALANCER:
+        pre      = '%s!handler!balancer!source'%(rule)
+        src_keys = CTK.cfg.keys(pre)
+        for src_key in src_keys:
+            sources.append (CTK.cfg.get_val('%s!%s'%(pre,src_key)))
 
-    for src_key in src_keys:
-        sources.append (CTK.cfg.get_val('%s!%s'%(pre,src_key)))
     return list(set(sources))
 
 
@@ -177,11 +183,12 @@ def _rules_per_source (source):
         rule_pre, sources = rule_dict.items()[0]
         if source in sources:
             pre = '%s!handler!balancer!source'%(rule_pre)
-            balanced = CTK.cfg.keys(pre)
+            balanced = CTK.cfg.keys (pre)
             for src in balanced:
                 rule = '%s!%s'%(pre,src)
                 if CTK.cfg.get_val(rule) == source:
-                    rules.append(rule)
+                    rules.append (rule)
+
     return list(set(rules))
 
 
@@ -264,6 +271,7 @@ class Render_Source:
             CTK.Container.__init__ (self)
 
             table = CTK.Table({'id': 'source-usage'})
+            self += CTK.RawHTML ("<h2>%s</h2>" % (_('Source Usage')))
             self += table
             table.set_header(1)
             table += [CTK.RawHTML(x) for x in (_('Virtual Server'), _('Rule'))]
@@ -292,7 +300,7 @@ class Render_Source:
         nick = CTK.cfg.get_val('source!%s!nick'%(num))
 
         cont = CTK.Container()
-        cont += CTK.RawHTML ('<h2>Source: %s</h2>'%(CTK.escape_html (nick)))
+        cont += CTK.RawHTML ('<h2>%s: %s</h2>'%(_('Source'), CTK.escape_html (nick)))
 
         workarea = CTK.Box ({'id': 'source-workarea'})
 
@@ -300,8 +308,11 @@ class Render_Source:
         table.Add (_('Type'),       CTK.ComboCfg ('source!%s!type'%(num), trans_options(SOURCE_TYPES)), _(NOTE_TYPE))
         table.Add (_('Nick'),       CTK.TextCfg ('source!%s!nick'%(num), False), _(NOTE_NICK))
         table.Add (_('Connection'), CTK.TextCfg ('source!%s!host'%(num), False), _(NOTE_HOST))
+
         if tipe == 'interpreter':
-            table.Add (_('Interpreter'),         CTK.TextCfg ('source!%s!interpreter'%(num),   False), _(NOTE_INTERPRETER))
+            NOTE_INTERPRETER = _(NOTE_INTERPRETER1) + '<br/>' + '<b>%s</b>'%(_(NOTE_INTERPRETER2))
+
+            table.Add (_('Interpreter'),         CTK.TextCfg ('source!%s!interpreter'%(num),   False), NOTE_INTERPRETER)
             table.Add (_('Spawning timeout'),    CTK.TextCfg ('source!%s!timeout'%(num),       True),  _(NOTE_TIMEOUT))
             table.Add (_('Execute as User'),     CTK.TextCfg ('source!%s!user'%(num),          True),  _(NOTE_USER))
             table.Add (_('Execute as Group'),    CTK.TextCfg ('source!%s!group'%(num),         True),  _(NOTE_GROUP))
@@ -311,7 +322,8 @@ class Render_Source:
         submit += table
         workarea += submit
 
-        if CTK.cfg.get_val ('source!%s!env_inherited'%(num)) == '0':
+        if CTK.cfg.get_val ('source!%s!type'%(num)) == 'interpreter' and \
+           CTK.cfg.get_val ('source!%s!env_inherited'%(num)) == '0':
             workarea += EnvironmentWidget (num)
 
         sources = _all_sources_per_rule ()
@@ -404,9 +416,10 @@ class Render:
                     r = Rule.Rule('%s!match' %(rule_pre))
                     rule_name = r.GetName()
                     rule_link = rule_pre.replace('!','/')
-                    links.append(CTK.consts.LINK_HREF%(rule_link, rule_name))
+                    links.append (CTK.consts.LINK_HREF %(rule_link, rule_name))
 
                 dialog  = CTK.Dialog ({'title': _('Deletion is forbidden'), 'width': 480})
+                dialog += CTK.RawHTML (_('<h2>%s</h2>' %(_("Configuration consistency"))))
                 dialog += CTK.RawHTML (_(NOTE_FORBID_1))
                 dialog += CTK.RawHTML ('<p>%s: %s</p>'%(_(NOTE_FORBID_2), ', '.join(links)))
                 dialog.AddButton (_('Close'), "close")
@@ -493,4 +506,4 @@ CTK.publish ('^%s/\d+$'          %(URL_BASE), Render_Particular)
 CTK.publish ('^%s/content/[\d]+$'%(URL_BASE), Render_Source)
 CTK.publish ('^%s/content/empty$'%(URL_BASE), Render_Source)
 CTK.publish ('^%s/content/[\d]+/clone$'%(URL_BASE), commit_clone)
-CTK.publish ('^%s$'              %(URL_APPLY), commit, validation=VALIDATIONS, method="POST")
+CTK.publish ('^%s'               %(URL_APPLY), commit, validation=VALIDATIONS, method="POST")
