@@ -5,7 +5,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2001-2010 Alvaro Lopez Ortega
+# Copyright (C) 2001-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -45,7 +45,7 @@ NOTE_NICKNAME         = N_('Nickname for the virtual server.')
 NOTE_CERT             = N_('This directive points to the PEM-encoded Certificate file for the server (Full path to the file)')
 NOTE_CERT_KEY         = N_('PEM-encoded Private Key file for the server (Full path to the file)')
 NOTE_CA_LIST          = N_('File containing the trusted CA certificates, utilized for checking the client certificates (Full path to the file)')
-NOTE_CIPHERS          = N_('Ciphers that TLS/SSL is allowed to use. <a target="_blank" href="http://www.openssl.org/docs/apps/ciphers.html">Reference</a>. (Default: all ciphers supported by the OpenSSL version used).')
+NOTE_CIPHERS          = N_('Ciphers that TLS/SSL is allowed to use. <a target="_blank" href="http://www.openssl.org/docs/apps/ciphers.html">Reference</a>. (Default: HIGH:!aNULL:!MD5).')
 NOTE_CLIENT_CERTS     = N_('Skip, Accept or Require client certificates.')
 NOTE_VERIFY_DEPTH     = N_('Limit up to which depth certificates in a chain are used during the verification procedure (Default: 1)')
 NOTE_ERROR_HANDLER    = N_('Allows the selection of how to generate the error responses.')
@@ -67,14 +67,43 @@ NOTE_X_REAL_IP        = N_('Whether the logger should read and use the X-Real-IP
 NOTE_X_REAL_IP_ALL    = N_('Accept all the X-Real-IP and X-Forwarded-For headers. WARNING: Turn it on only if you are centain of what you are doing.')
 NOTE_X_REAL_IP_ACCESS = N_('List of IP addresses and subnets that are allowed to send X-Real-IP and X-Forwarded-For headers.')
 NOTE_EVHOST           = N_('How to support the "Advanced Virtual Hosting" mechanism. (Default: off)')
-NOTE_LOGGER_TEMPLATE  = N_('The following variables are accepted: <br/>${ip_remote}, ${ip_local}, ${protocol}, ${transport}, ${port_server}, ${query_string}, ${request_first_line}, ${status}, ${now}, ${time_secs}, ${time_nsecs}, ${user_remote}, ${request}, ${request_original}, ${vserver_name}, ${vserver_name_req}, ${response_size}')
+NOTE_LOGGER_TEMPLATE  = N_('The following variables are accepted: ')
 NOTE_MATCHING_METHOD  = N_('Allows the selection of domain matching method.')
 NOTE_COLLECTOR        = N_('Whether or not it should collected statistics about the traffic of this virtual server.')
 NOTE_UTC_TIME         = N_('Time standard to use in the log file entries.')
 NOTE_INDEX_USAGE      = N_('Remember that only "File Exists" rules and "List & Send" handlers use the Directory Indexes setting.')
+NOTE_MATCH_NICK       = N_('Use this nickname as an additional host name for this virtual server (Default: yes)')
+NOTE_HSTS             = N_('Enforce HTTPS by using the HTTP Strict Transport Security.')
+NOTE_HSTS_MAXAGE      = N_("How long the client's browser should remember the forced HTTPS (in seconds).")
+NOTE_HSTS_SUBDOMAINS  = N_("Should HSTS be used in all the subdomains of this virtual verser (Default: yes).")
 
 DEFAULT_HOST_NOTE     = N_("<p>The 'default' virtual server matches all the domain names.</p>")
 
+CUSTOM_MACROS_LIST = [
+    ('ip_remote',          N_("Remote IP address")),
+    ('ip_local',           N_("Local IP address")),
+    ('protocol',           N_("Request Protocol")),
+    ('transport',          N_("Transport type: http or https")),
+    ('port_server',        N_("Port of the server serving the request")),
+    ('query_string',       N_("The query string, if exists")),
+    ('request_first_line', N_("First line of HTTP request")),
+    ('status',             N_("Response status code")),
+    ('now',                N_("Time: in common log format time format")),
+    ('time_secs',          N_("Time: seconds since Epoch")),
+    ('time_msecs',         N_("Time: milliseconds since Epoch")),
+    ('user_remote',        N_("Remote user (authentication)")),
+    ('request',            N_("URL path requested")),
+    ('request_original',   N_("URL path requested before any rewrite")),
+    ('vserver_name',       N_("Virtual Server nick name")),
+    ('vserver_name_req',   N_("Requested host (Host: header)")),
+    ('response_size',      N_("Size of the response in bytes")),
+    ('http_host',          N_("'Host:' header of the request")),
+    ('http_referrer',      N_("'Referrer:' header of the request")),
+    ('http_user_agent',    N_("'User-Agent:' header of the request")),
+    ('http_cookie',        N_("'Cookie:' header of the request")),
+]
+
+
 JS_TR_ODD = """
 $('#rules-table tr:odd').addClass('trodd');
 """
@@ -98,7 +127,9 @@ VALIDATIONS = [
     ("vserver![\d]+!ssl_certificate_key_file",   validations.is_local_file_exists),
     ("vserver![\d]+!ssl_ca_list_file",           validation_ca_list),
     ("vserver![\d]+!ssl_verify_depth",           validations.is_positive_int),
-    ("vserver![\d]+!logger!.+?!filename",        validations.parent_is_dir),
+    ("vserver![\d]+!error_writer!filename",      validations.can_create_file),
+    ("vserver![\d]+!error_writer!command",       validations.is_local_file_exists),
+    ("vserver![\d]+!logger!.+?!filename",        validations.can_create_file),
     ("vserver![\d]+!logger!.+?!command",         validations.is_local_file_exists),
     ("vserver![\d]+!logger!x_real_ip_access$",   validations.is_ip_or_netmask_list),
 ]
@@ -116,12 +147,12 @@ BEHAVIOR_TAGS = [
     (N_('Custom Document Root'), N_('Root')),
     (N_('Only HTTPS'),           N_('Secure')),
     (N_('Encoders'),             N_('Enc')),
+    (N_('Cacheable'),            N_('Cache')),
     (N_('Expiration'),           N_('Exp')),
     (N_('Connection Timeout'),   N_('Timeout')),
     (N_('Traffic Shaping'),      N_('Shaping')),
     (N_('Logging Enabled'),      N_('Log')),
     (N_('Rule is Final'),        N_('Final')),
-    (N_('Rule is Active'),       N_('Enabled'))
 ]
 
 
@@ -138,6 +169,23 @@ def commit_clone():
     return CTK.cfg_reply_ajax_ok()
 
 
+class HostMatchWidget_GeneralProps (CTK.Container):
+    def __init__ (self, vsrv_num, refresh):
+        CTK.Container.__init__ (self)
+
+        pre       = "vserver!%s" %(vsrv_num)
+        url_apply = "%s/%s" %(URL_APPLY, vsrv_num)
+
+        if CTK.cfg.get_val ('%s!match'%(pre)):
+            table = CTK.PropsAuto (url_apply)
+            table.Add (_('Match nickname'), CTK.CheckCfgText('%s!match!nick'%(pre), True, _('Match')), _(NOTE_MATCH_NICK))
+            submit = CTK.Submitter (url_apply)
+            submit += CTK.Indenter (table)
+
+            self += CTK.RawHTML ('<h2>%s</h2>' %(_('Host Match')))
+            self += submit
+
+
 class HostMatchWidget (CTK.Container):
     def __init__ (self, vsrv_num):
         CTK.Container.__init__ (self)
@@ -147,8 +195,6 @@ class HostMatchWidget (CTK.Container):
         is_default = CTK.cfg.get_lowest_entry("vserver") == int(vsrv_num)
         is_complex = CTK.cfg.get_val ('%s!match'%(pre)) == 'v_or'
 
-        self += CTK.RawHTML ('<h2>%s</h2>' %(_('Host Match')))
-
         # Default Virtual Server
         if is_default:
             notice  = CTK.Notice()
@@ -158,6 +204,12 @@ class HostMatchWidget (CTK.Container):
 
         # Complex matches
         if is_complex:
+            # General Properties
+            refresh = CTK.Refreshable ({'id': 'vserver_match_props'})
+            refresh.register (lambda: HostMatchWidget_GeneralProps(vsrv_num, refresh).Render())
+            self += refresh
+
+            # Left side rule
             table = CTK.PropsAuto (url_apply)
             modul = CTK.PluginSelector ('%s!match!left'%(pre), trans_options(Cherokee.support.filter_available(VRULES)), vsrv_num=vsrv_num)
             table.Add ('%s 1'%(_('Method')), modul.selector_widget, _(NOTE_MATCHING_METHOD), False)
@@ -166,11 +218,14 @@ class HostMatchWidget (CTK.Container):
 
             submit = CTK.Submitter ('%s/%s/vmatch'%(URL_APPLY, vsrv_num))
             submit += CTK.Hidden ('op', 'del_1')
+            submit.bind ('submit_success', refresh.JS_to_refresh())
+
             remove_1 = CTK.Link (None, CTK.RawHTML(_('Remove criteria')))
             remove_1.bind ('click', submit.JS_to_submit())
             self += submit
             self += remove_1
 
+            # Right side rule
             table = CTK.PropsAuto (url_apply)
             modul = CTK.PluginSelector ('%s!match!right'%(pre), trans_options(Cherokee.support.filter_available(VRULES)), vsrv_num=vsrv_num)
             table.Add ('%s 2'%(_('Method')), modul.selector_widget, _(NOTE_MATCHING_METHOD), False)
@@ -179,6 +234,8 @@ class HostMatchWidget (CTK.Container):
 
             submit = CTK.Submitter ('%s/%s/vmatch'%(URL_APPLY, vsrv_num))
             submit += CTK.Hidden ('op', 'del_2')
+            submit.bind ('submit_success', refresh.JS_to_refresh())
+
             remove_2 = CTK.Link (None, CTK.RawHTML(_('Remove criteria')))
             remove_2.bind ('click', submit.JS_to_submit())
             self += submit
@@ -186,9 +243,18 @@ class HostMatchWidget (CTK.Container):
 
         # Simple match
         else:
+            # General Properties
+            refresh = CTK.Refreshable ({'id': 'vserver_match_props'})
+            refresh.register (lambda: HostMatchWidget_GeneralProps(vsrv_num, refresh).Render())
+            self += refresh
+
+            # Match module
             table = CTK.PropsAuto (url_apply)
             modul = CTK.PluginSelector ('%s!match'%(pre), trans_options(Cherokee.support.filter_available(VRULES)), vsrv_num=vsrv_num)
+            modul.selector_widget.bind ('changed', refresh.JS_to_refresh())
             table.Add (_('Method'), modul.selector_widget, _(NOTE_MATCHING_METHOD), False)
+
+            self += CTK.RawHTML ('<h2>%s</h2>' %(_('How to match this Virtual Server')))
             self += CTK.Indenter (table)
             self += modul
 
@@ -305,7 +371,7 @@ class BehaviorWidget (CTK.Container):
         rule_name = rule.GetName()
         link = RuleLink (vsrv_num, r, CTK.RawHTML ('<span title="%s">%s</span>' %(rule_name, rule_name)))
 
-        handler, auth, root, secure, enc, exp, timeout, shaping, log, final, active = [None for x in range(11)]
+        handler, auth, root, secure, enc, exp, flcache, timeout, shaping, log, final, active = [None for x in range(12)]
 
         tmp = CTK.cfg.get_val ('vserver!%s!rule!%s!handler'%(vsrv_num, r), '')
         if tmp:
@@ -361,14 +427,15 @@ class BehaviorWidget (CTK.Container):
             tmp   = _('Prevents further rule evaluation')
             final = CTK.ImageStock('tick', {'alt': tmp, 'title': tmp})
 
-        tmp = not bool (int (CTK.cfg.get_val('vserver!%s!rule!%s!disabled'%(vsrv_num,r), "0")))
-        if tmp:
-            tmp    = _('Rule is active')
-            active = CTK.ImageStock('tick', {'alt': tmp, 'title': tmp})
-        else:
-            active = CTK.Box({'class': 'inactive-rule'})
+        tmp = CTK.cfg.get_val('vserver!%s!rule!%s!flcache'%(vsrv_num,r))
+        if tmp in ('allow', '1'):
+            tmp     = _('Content can be cached')
+            flcache = CTK.ImageStock('tick', {'alt': tmp, 'title': tmp})
+        elif tmp in ('forbid', '0'):
+            tmp     = _('Forbids content caching')
+            flcache = CTK.ImageStock ('forbid', {'alt': tmp, 'title': tmp})
 
-        return [link, handler, auth, root, secure, enc, exp, timeout, shaping, log, final, active]
+        return [link, handler, auth, root, secure, enc, flcache, exp, timeout, shaping, log, final]
 
 
 class BasicsWidget (CTK.Container):
@@ -431,10 +498,9 @@ class BasicsWidget (CTK.Container):
             if CTK.cfg.get_val(key) in matches:
                 return True
 
-            for k in CTK.cfg[key].keys():
+            for k in CTK.cfg.keys(key):
                 if recursive_find ('%s!%s' %(key,k)):
                     return True
-
             return False
 
         if recursive_find (key):
@@ -517,9 +583,20 @@ class LogginWidgetContent (CTK.Container):
                 table.Add (_('Command'), submit, _(NOTE_WRT_EXEC))
 
             if format == 'custom':
+                table_macros = CTK.Table ({'class': 'custom-logger-macros'})
+                for macro, desc in CUSTOM_MACROS_LIST:
+                    table_macros += [CTK.RawHTML('${%s}'%(macro)), CTK.RawHTML (_(desc))]
+
+                collaps  = CTK.CollapsibleEasy ((_('Show macros'), _('Hide')))
+                collaps += table_macros
+
+                macros = CTK.Container()
+                macros += CTK.RawHTML (_(NOTE_LOGGER_TEMPLATE))
+                macros += collaps
+
                 submit = CTK.Submitter(url_apply)
                 submit += CTK.TextCfg('%s!access_template'%(pre))
-                table.Add (_('Template: '), submit, _(NOTE_LOGGER_TEMPLATE))
+                table.Add (_('Template: '), submit, macros)
 
         self += CTK.RawHTML ('<h2>%s</h2>' % (_('Access Logging')))
         self += CTK.Indenter (table)
@@ -603,6 +680,21 @@ class SecutiryWidgetContent (CTK.Container):
         self += CTK.RawHTML ('<h2>%s</h2>' % (_('Advanced Options')))
         self += CTK.Indenter (submit)
 
+        # HSTS
+        table = CTK.PropsTable()
+        table.Add (_('Enable HSTS'), CTK.CheckCfgText ('%s!hsts'%(pre), False, _('Accept')), _(NOTE_HSTS))
+
+        if int(CTK.cfg.get_val('%s!hsts' %(pre), "0")):
+            table.Add (_('HSTS Max-Age'),       CTK.TextCfg ('%s!hsts!max_age'%(pre), True, {'optional_string':_("One year")}), _(NOTE_HSTS_MAXAGE))
+            table.Add (_('Include Subdomains'), CTK.CheckCfgText ('%s!subdomains'%(pre), True, _('Include all')), _(NOTE_HSTS_SUBDOMAINS))
+
+        submit = CTK.Submitter (url_apply)
+        submit.bind ('submit_success', refreshable.JS_to_refresh())
+        submit += table
+
+        self += CTK.RawHTML ('<h2>%s</h2>' % (_('HTTP Strict Transport Security (HSTS)')))
+        self += CTK.Indenter (submit)
+
 
 class SecurityWidget (CTK.Container):
     def __init__ (self, vsrv_num):
@@ -646,8 +738,8 @@ class Render:
 
 
 CTK.publish (r'^%s/[\d]+$'        %(URL_BASE),  Render)
-CTK.publish (r'^%s/[\d]+$'        %(URL_APPLY), CTK.cfg_apply_post,        validation=VALIDATIONS, method="POST")
-CTK.publish (r'^%s/[\d]+/log$'    %(URL_APPLY), LogginWidgetContent_Apply, validation=VALIDATIONS, method="POST")
-CTK.publish (r'^%s/[\d]+/vmatch$' %(URL_APPLY), HostMatchWidget_Apply, method="POST")
+CTK.publish (r'^%s/[\d]+'         %(URL_APPLY), CTK.cfg_apply_post,        method="POST", validation=VALIDATIONS)
+CTK.publish (r'^%s/[\d]+/log'     %(URL_APPLY), LogginWidgetContent_Apply, method="POST", validation=VALIDATIONS)
+CTK.publish (r'^%s/[\d]+/vmatch'  %(URL_APPLY), HostMatchWidget_Apply,     method="POST")
 CTK.publish (r'^%s/[\d]+/clone$'  %(URL_BASE),  commit_clone)
 
