@@ -7,7 +7,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2001-2010 Alvaro Lopez Ortega
+# Copyright (C) 2001-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -28,6 +28,7 @@
 import os
 import sys
 import stat
+import socket
 import signal
 import thread
 
@@ -35,10 +36,12 @@ import thread
 sys.path.append (os.path.abspath (os.path.realpath(__file__) + '/../CTK'))
 import CTK
 import OWS_Login
+import market.Distro
 
 # Cherokee imports
 import config_version
 from configured import *
+import PageError
 
 
 def init (scgi_port, cfg_file):
@@ -72,7 +75,14 @@ def init (scgi_port, cfg_file):
 
     # Init CTK
     if scgi_port.isdigit():
-        CTK.init (port=int(scgi_port))
+        # Ensure that 'localhost' can be resolved
+        try:
+            socket.getaddrinfo ("localhost", int(scgi_port))
+        except socket.gaierror:
+            print >> sys.stderr, "[FATAL ERROR]: The 'localhost' host name cannot be resolved.\n"
+            sys.exit(1)
+
+        CTK.init (host="localhost", port=int(scgi_port), sec_cookie=True, sec_submit=True)
 
     else:
         # Remove the unix socket if it already exists
@@ -84,7 +94,7 @@ def init (scgi_port, cfg_file):
         except OSError:
             pass
 
-        CTK.init (unix_socket=scgi_port)
+        CTK.init (unix_socket=scgi_port, sec_cookie=True, sec_submit=True)
 
     # At this moment, CTK must be forced to work as a syncronous
     # server. All the initial tests (config file readable, correct
@@ -123,20 +133,12 @@ def debug_set_up():
     signal.signal (signal.SIGUSR2, trace_callback)
 
 
-def do_OWS_login():
-    def thread_func (username, password):
-        try:
-            OWS_Login.log_in (username, password)
-        except ProtocolError:
-            # Do not give up so easily
-            OWS_Login.log_in (username, password)
+def download_distro_index():
+    def thread_func():
+        # First instance will trigger the update
+        index = market.Distro.Index()
 
-    username   = CTK.cfg.get_val("admin!ows!login!user")
-    password   = CTK.cfg.get_val("admin!ows!login!password")
-    ows_enable = int(CTK.cfg.get_val("admin!ows!enabled", OWS_ENABLE))
-
-    if all((ows_enable, username, password)):
-        thread.start_new_thread (thread_func, (username, password))
+    thread.start_new_thread (thread_func, ())
 
 
 if __name__ == "__main__":
@@ -161,7 +163,6 @@ if __name__ == "__main__":
         return reduce (lambda x,y: x and y, tmp)
 
     if not are_vsrvs_num():
-        import PageError
         CTK.publish (r'', PageError.AncientConfig, file=cfg_file)
 
         while not are_vsrvs_num():
@@ -171,7 +172,6 @@ if __name__ == "__main__":
 
     # Check config file and set up
     if os.path.exists (cfg_file) and os.path.isdir (cfg_file):
-        import PageError
         CTK.publish (r'', PageError.NotWritable, file=cfg_file)
 
         while os.path.isdir (cfg_file):
@@ -191,7 +191,6 @@ if __name__ == "__main__":
         CTK.cfg.load()
 
     if not os.access (cfg_file, os.W_OK):
-        import PageError
         CTK.publish (r'', PageError.NotWritable, file=cfg_file)
 
         while not os.access (cfg_file, os.W_OK):
@@ -199,14 +198,14 @@ if __name__ == "__main__":
 
         CTK.unpublish (r'')
 
-    if not os.path.isdir (CHEROKEE_ICONSDIR):
-        import PageError
-        CTK.publish (r'', PageError.IconsMissing, path=CHEROKEE_ICONSDIR)
+    for path in (CHEROKEE_WORKER, CHEROKEE_SERVER, CHEROKEE_ICONSDIR):
+        if not os.path.exists (path):
+            CTK.publish (r'', PageError.ResourceMissing, path=CHEROKEE_WORKER)
 
-        while not os.path.isdir (CHEROKEE_ICONSDIR):
-            CTK.step()
+            while not os.path.exists (path):
+                CTK.step()
 
-        CTK.unpublish (r'')
+            CTK.unpublish (r'')
 
     # OWS related checks
     if not os.path.isdir (CHEROKEE_OWS_DIR):
@@ -219,8 +218,6 @@ if __name__ == "__main__":
 
     if not os.access (CHEROKEE_OWS_DIR,  os.W_OK) or \
        not os.access (CHEROKEE_OWS_ROOT, os.W_OK):
-        import PageError
-
         CTK.publish (r'', PageError.OWSDirectory)
         while not os.access (CHEROKEE_OWS_DIR,  os.W_OK) or \
               not os.access (CHEROKEE_OWS_ROOT, os.W_OK):
@@ -262,6 +259,11 @@ if __name__ == "__main__":
     import PageStatus
     import market
 
+    # Wizards 2.0 (TMP!)
+    wizards2_path = os.path.realpath (__file__ + "/../wizards2")
+    if os.path.exists (wizards2_path):
+        import wizards2
+
     # Init translation
     if CTK.cfg['admin!lang']:
         PageIndex.language_set (CTK.cfg.get_val('admin!lang'))
@@ -270,8 +272,19 @@ if __name__ == "__main__":
     CTK.set_synchronous (False)
 
     # Log into OWS if feature is enabled
-    do_OWS_login()
+    ## do_OWS_login()
+    download_distro_index()
 
     # Run forever
     CTK.run()
 
+    # Kill lingering processes
+    try:
+        # Parent
+        cherokee_admin_pid = os.getppid()
+        os.kill (cherokee_admin_pid, signal.SIGTERM)
+
+        # Itself
+        os.killpg (0, signal.SIGTERM)
+    except OSError:
+        pass
