@@ -24,10 +24,12 @@
 #
 
 import re
+import os
 import CTK
 import Wizard
 import validations
 import popen
+import market
 
 from util import *
 
@@ -59,6 +61,7 @@ DEFAULT_PATHS = ['/usr/bin',
                  '/usr/gnu/bin',
                  '/usr/local/bin',
                  '/opt/local/bin',
+                 '/usr/php/*.*/bin',
                  '/usr/pkg/libexec/cgi-bin',
                  # FPM
                  '/usr/sbin',
@@ -85,7 +88,8 @@ STD_ETC_PATHS = ['/etc/php.ini',
                  '/opt/local/etc/php*/php.ini',
                  '/etc/php*/*/php.ini',
                  '/etc/php*/php.ini',
-		 '/var/www/conf/php.ini']
+                 '/usr/local/lib*/php.ini',
+                 '/var/www/conf/php.ini']
 
 CFG_PREFIX    = 'tmp!wizard!php'
 
@@ -168,6 +172,13 @@ def wizard_php_add (key):
         CTK.cfg['%s!encoder!gzip' %(next)]              = '1'
         CTK.cfg['%s!timeout' %(next)]                   = timeout
 
+        # Front-Line Cache
+        CTK.cfg['%s!flcache' %(next)]                   = 'allow'
+        CTK.cfg['%s!flcache!policy' %(next)]            = 'explicitly_allowed'
+
+        # GZip encoder
+        CTK.cfg['%s!encoder!gzip' %(next)]              = 'allow'
+
     # Index files
     indexes = filter (None, CTK.cfg.get_val ('%s!directory_index' %(key), '').split(','))
     if not 'index.php' in indexes:
@@ -226,13 +237,33 @@ def figure_php_information():
     return settings
 
 
+def figure_php_user (pre_vsrv):
+    """Determine PHP user/group accounting for config file, source UID, and server UID"""
+
+    server_user  = CTK.cfg.get_val ('server!user',  str(os.getuid()))
+    server_group = CTK.cfg.get_val ('server!group', str(os.getgid()))
+    php_info     = get_info (pre_vsrv)
+    interpreter  = CTK.cfg.get_val ('%s!interpreter' %(php_info['source']), '')
+
+    if 'fpm' in interpreter:
+        fpm_conf  = _figure_fpm_settings()
+        php_user  = fpm_conf.get('user',  server_user)
+        php_group = fpm_conf.get('group', server_group)
+    else:
+        php_user  = CTK.cfg.get_val ('%s!user'  %(php_info['source']), server_user)
+        php_group = CTK.cfg.get_val ('%s!group' %(php_info['source']), server_group)
+
+    return  {'php_user':  php_user,
+             'php_group': php_group}
+
+
 #
 # Public URLs
 #
 
 URL_WIZARD_RULE_R  = r'^/wizard/vserver/(\d+)/php$'
 URL_WIZARD_APPLY   = '/wizard/vserver/%s/php/apply'
-URL_WIZARD_APPLY_R = r'^/wizard/vserver/(\d+)/php/apply$'
+URL_WIZARD_APPLY_R = r'^/wizard/vserver/(\d+)/php/apply'
 URL_APPLY          = '/wizard/vserver/php/apply'
 
 class Commit:
@@ -380,7 +411,7 @@ CTK.publish (URL_WIZARD_APPLY_R, Commit, method="POST")
 CTK.publish ('^/wizard/vserver/php$',   WelcomeVserver)
 CTK.publish ('^/wizard/vserver/php/2$', DocumentRoot)
 CTK.publish ('^/wizard/vserver/php/3$', Host)
-CTK.publish (r'^%s$'%(URL_APPLY), Commit, method="POST", validation=VALS)
+CTK.publish (r'^%s'%(URL_APPLY),        Commit, method="POST", validation=VALS)
 
 
 #
@@ -453,16 +484,21 @@ def __figure_std_settings():
 
 
 def __figure_fpm_settings():
+    fpm_info = {}
+
     # Find config file
     paths = []
     for p in FPM_ETC_PATHS:
         paths.append (p)
         paths.append ('%s-*' %(p))
 
-    fpm_info = {}
-
     # For each configuration file
-    for conf_file in path_eval_exist (paths):
+    suitable_confs = path_eval_exist (paths)
+    if not suitable_confs:
+        return {}
+
+    # Read the configuration files
+    for conf_file in suitable_confs:
         # Read
         try:
             content = open (conf_file, 'r').read()
@@ -475,7 +511,7 @@ def __figure_fpm_settings():
             if tmp:
                 fpm_info['listen'] = tmp[0]
             else:
-                tmp = re.findall (r'^listen = (.*)', content)
+                tmp = re.findall (r'^listen *= *(.+)$', content, re.M)
                 if tmp:
                     fpm_info['listen']  = tmp[0]
 
@@ -485,7 +521,7 @@ def __figure_fpm_settings():
             if tmp:
                 fpm_info['timeout'] = tmp[0]
             else:
-                tmp = re.findall (r'^request_terminate_timeout[ ]*=[ ]*(\d*)s*', content)
+                tmp = re.findall (r'^request_terminate_timeout *= *(\d*)s*', content, re.M)
                 if tmp:
                     fpm_info['timeout'] = tmp[0]
 
@@ -494,6 +530,26 @@ def __figure_fpm_settings():
             if '.conf' in conf_file:
                 fpm_info['conf_file'] = conf_file
 
+        # User
+        if not fpm_info.get('user'):
+            tmp = re.findall (r'<value name="user">(.*?)</value>', content)
+            if tmp:
+                fpm_info['user'] = tmp[0]
+            else:
+                tmp = re.findall (r'^user *= *(.*)$', content, re.M)
+                if tmp:
+                    fpm_info['user'] = tmp[0]
+
+        # Group
+        if not fpm_info.get('group'):
+            tmp = re.findall (r'<value name="group">(.*?)</value>', content)
+            if tmp:
+                fpm_info['group'] = tmp[0]
+            else:
+                tmp = re.findall (r'^group *= *(.*)$', content, re.M)
+                if tmp:
+                    fpm_info['group'] = tmp[0]
+
     # Set last minute defaults
     if not fpm_info.get('timeout'):
          fpm_info['timeout'] = PHP_DEFAULT_TIMEOUT
@@ -538,7 +594,7 @@ def __source_add_fpm (php_path):
     if not fpm_info:
         raise Exception (_('Could not determine PHP-fpm settings.'))
 
-    host      = fpm_info['listen']
+    listen    = fpm_info['listen']
     conf_file = fpm_info['conf_file']
 
     # Add Source
@@ -546,9 +602,24 @@ def __source_add_fpm (php_path):
 
     CTK.cfg['%s!nick'        %(next)] = 'PHP Interpreter'
     CTK.cfg['%s!type'        %(next)] = 'interpreter'
-    CTK.cfg['%s!host'        %(next)] = host
+    CTK.cfg['%s!host'        %(next)] = listen
     CTK.cfg['%s!interpreter' %(next)] = '%(php_path)s --fpm-config %(conf_file)s' %(locals())
 
+    # In case FPM has specific UID/GID and differs from Cherokee's,
+    # the interpreter must by spawned by root.
+    #
+    server_user  = CTK.cfg.get_val ('server!user',  str(os.getuid()))
+    server_group = CTK.cfg.get_val ('server!group', str(os.getgid()))
+
+    root_user    = market.InstallUtil.get_installation_UID()
+    root_group   = market.InstallUtil.get_installation_GID()
+    php_user     = fpm_info.get('user',  server_user)
+    php_group    = fpm_info.get('group', server_group)
+
+    if php_user != server_user or php_group != server_group:
+        CTK.cfg['%s!user'  %(next)] = root_user
+        CTK.cfg['%s!group' %(next)] = root_group
+
     return next
 
 
